@@ -1,20 +1,20 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ar_EG">
+<TS version="2.1" language="ar">
 <context>
     <name>CronModel</name>
     <message>
-        <location filename="../CronModel.cpp" line="115"/>
+        <location filename="../CronModel.cpp" line="112"/>
         <source>Time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../CronModel.cpp" line="117"/>
+        <location filename="../CronModel.cpp" line="114"/>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../CronModel.cpp" line="119"/>
+        <location filename="../CronModel.cpp" line="116"/>
         <source>Command</source>
         <translation type="unfinished"></translation>
     </message>
@@ -22,22 +22,22 @@
 <context>
     <name>ExecuteList</name>
     <message>
-        <location filename="../ExecuteList.cpp" line="36"/>
+        <location filename="../ExecuteList.cpp" line="39"/>
         <source>Max Item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ExecuteList.cpp" line="38"/>
+        <location filename="../ExecuteList.cpp" line="41"/>
         <source>Max Date</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ExecuteList.cpp" line="40"/>
+        <location filename="../ExecuteList.cpp" line="43"/>
         <source>Select</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ExecuteList.cpp" line="44"/>
+        <location filename="../ExecuteList.cpp" line="48"/>
         <source>&amp;Update</source>
         <translation type="unfinished"></translation>
     </message>
@@ -45,22 +45,22 @@
 <context>
     <name>ExecuteModel</name>
     <message>
-        <location filename="../ExecuteModel.cpp" line="63"/>
+        <location filename="../ExecuteModel.cpp" line="62"/>
         <source>Execute Time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ExecuteModel.cpp" line="65"/>
+        <location filename="../ExecuteModel.cpp" line="64"/>
         <source>Time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ExecuteModel.cpp" line="67"/>
+        <location filename="../ExecuteModel.cpp" line="66"/>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ExecuteModel.cpp" line="69"/>
+        <location filename="../ExecuteModel.cpp" line="68"/>
         <source>Command</source>
         <translation type="unfinished"></translation>
     </message>
@@ -68,198 +68,226 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../MainWindow.cpp" line="48"/>
+        <location filename="../MainWindow.cpp" line="51"/>
         <source>&amp;Command</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="50"/>
+        <location filename="../MainWindow.cpp" line="54"/>
         <source>&amp;Variables</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="52"/>
+        <location filename="../MainWindow.cpp" line="57"/>
         <source>&amp;Job List</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="93"/>
-        <location filename="../MainWindow.cpp" line="183"/>
-        <location filename="../MainWindow.cpp" line="185"/>
-        <location filename="../MainWindow.cpp" line="234"/>
-        <location filename="../MainWindow.cpp" line="255"/>
-        <location filename="../MainWindow.cpp" line="329"/>
+        <location filename="../MainWindow.cpp" line="99"/>
+        <location filename="../MainWindow.cpp" line="191"/>
+        <location filename="../MainWindow.cpp" line="236"/>
+        <location filename="../MainWindow.cpp" line="256"/>
+        <location filename="../MainWindow.cpp" line="325"/>
         <source>Job Scheduler</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="110"/>
+        <location filename="../MainWindow.cpp" line="124"/>
         <source>&amp;File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="111"/>
+        <location filename="../MainWindow.cpp" line="125"/>
         <source>File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="114"/>
+        <location filename="../MainWindow.cpp" line="128"/>
         <source>&amp;New Item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="115"/>
+        <location filename="../MainWindow.cpp" line="129"/>
         <source>Ctrl+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="118"/>
+        <location filename="../MainWindow.cpp" line="132"/>
         <source>&amp;Reload</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="119"/>
+        <location filename="../MainWindow.cpp" line="133"/>
         <source>Ctrl+R</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="121"/>
+        <location filename="../MainWindow.cpp" line="135"/>
         <source>&amp;Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="122"/>
+        <location filename="../MainWindow.cpp" line="136"/>
         <source>Ctrl+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="125"/>
+        <location filename="../MainWindow.cpp" line="139"/>
         <source>Start as &amp;Root</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="127"/>
+        <location filename="../MainWindow.cpp" line="141"/>
         <source>Start as &amp;Regular user</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="128"/>
+        <location filename="../MainWindow.cpp" line="142"/>
         <source>Ctrl+U</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="132"/>
+        <location filename="../MainWindow.cpp" line="145"/>
         <source>E&amp;xit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="133"/>
+        <location filename="../MainWindow.cpp" line="146"/>
         <source>Ctrl+Q</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="140"/>
+        <location filename="../MainWindow.cpp" line="153"/>
         <source>&amp;Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="141"/>
+        <location filename="../MainWindow.cpp" line="154"/>
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="143"/>
+        <location filename="../MainWindow.cpp" line="156"/>
         <source>Cu&amp;t</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="144"/>
+        <location filename="../MainWindow.cpp" line="157"/>
         <source>Ctrl+X</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+X</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="146"/>
+        <location filename="../MainWindow.cpp" line="159"/>
         <source>&amp;Copy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="147"/>
+        <location filename="../MainWindow.cpp" line="160"/>
         <source>Ctrl+C</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+C</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="149"/>
+        <location filename="../MainWindow.cpp" line="162"/>
         <source>&amp;Paste</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="150"/>
+        <location filename="../MainWindow.cpp" line="163"/>
         <source>Ctrl+V</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+V</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="153"/>
+        <location filename="../MainWindow.cpp" line="166"/>
         <source>&amp;Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="154"/>
+        <location filename="../MainWindow.cpp" line="167"/>
         <source>Del</source>
-        <translation type="unfinished"></translation>
+        <translation>حذف</translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="165"/>
-        <location filename="../MainWindow.cpp" line="168"/>
+        <location filename="../MainWindow.cpp" line="178"/>
+        <location filename="../MainWindow.cpp" line="180"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="167"/>
+        <location filename="../MainWindow.cpp" line="179"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="235"/>
+        <location filename="../MainWindow.cpp" line="237"/>
         <source>Not saved since last change.
 Are you OK to reload?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="330"/>
+        <location filename="../MainWindow.cpp" line="325"/>
         <source>Not saved since last change.
 Are you OK to exit?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="342"/>
+        <location filename="../MainWindow.cpp" line="338"/>
         <source>About Job Scheduler</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="343"/>
+        <location filename="../MainWindow.cpp" line="339"/>
         <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="343"/>
+        <location filename="../MainWindow.cpp" line="339"/>
         <source>Version: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="344"/>
+        <location filename="../MainWindow.cpp" line="340"/>
         <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="345"/>
+        <location filename="../MainWindow.cpp" line="343"/>
         <source>Original project page: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MainWindow.cpp" line="346"/>
+        <location filename="../MainWindow.cpp" line="347"/>
         <source>MX project page: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../MainWindow.cpp" line="352"/>
+        <source>%1 License</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../about.cpp" line="52"/>
+        <source>License</source>
+        <translation>رخصة</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="53"/>
+        <location filename="../about.cpp" line="62"/>
+        <source>Changelog</source>
+        <translation>التغيرات</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation>إلغاء</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="74"/>
+        <source>&amp;Close</source>
+        <translation>&amp;اغلاق</translation>
+    </message>
 </context>
 <context>
     <name>SaveDialog</name>
@@ -287,47 +315,47 @@ Are you OK to exit?</source>
 <context>
     <name>TCommandEdit</name>
     <message>
-        <location filename="../TCommandEdit.cpp" line="37"/>
+        <location filename="../TCommandEdit.cpp" line="41"/>
         <source>User:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="45"/>
+        <location filename="../TCommandEdit.cpp" line="49"/>
         <source>Time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="48"/>
+        <location filename="../TCommandEdit.cpp" line="53"/>
         <source>Time String E&amp;ditor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="52"/>
+        <location filename="../TCommandEdit.cpp" line="57"/>
         <source>Command:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="58"/>
+        <location filename="../TCommandEdit.cpp" line="63"/>
         <source>Comment:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="61"/>
+        <location filename="../TCommandEdit.cpp" line="66"/>
         <source>Job Schedule:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="123"/>
+        <location filename="../TCommandEdit.cpp" line="128"/>
         <source>Time Format Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="140"/>
+        <location filename="../TCommandEdit.cpp" line="146"/>
         <source>Today</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TCommandEdit.cpp" line="142"/>
+        <location filename="../TCommandEdit.cpp" line="148"/>
         <source>Tomorrow</source>
         <translation type="unfinished"></translation>
     </message>
@@ -335,67 +363,67 @@ Are you OK to exit?</source>
 <context>
     <name>TimeDialog</name>
     <message>
-        <location filename="../TimeDialog.cpp" line="74"/>
+        <location filename="../TimeDialog.cpp" line="76"/>
         <source>time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="79"/>
+        <location filename="../TimeDialog.cpp" line="81"/>
         <source>Minute</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="91"/>
+        <location filename="../TimeDialog.cpp" line="93"/>
         <source>Hour</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="97"/>
+        <location filename="../TimeDialog.cpp" line="99"/>
         <source>AM </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="103"/>
+        <location filename="../TimeDialog.cpp" line="105"/>
         <source>PM </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="110"/>
+        <location filename="../TimeDialog.cpp" line="112"/>
         <source>Day</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="125"/>
+        <location filename="../TimeDialog.cpp" line="127"/>
         <source>Month</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="139"/>
+        <location filename="../TimeDialog.cpp" line="141"/>
         <source>Week</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="151"/>
+        <location filename="../TimeDialog.cpp" line="153"/>
         <source>Simple</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="165"/>
+        <location filename="../TimeDialog.cpp" line="167"/>
         <source>Enable Literal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="167"/>
+        <location filename="../TimeDialog.cpp" line="169"/>
         <source>&amp;Reset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="168"/>
+        <location filename="../TimeDialog.cpp" line="170"/>
         <source>&amp;Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TimeDialog.cpp" line="169"/>
+        <location filename="../TimeDialog.cpp" line="171"/>
         <source>&amp;Ok</source>
         <translation type="unfinished"></translation>
     </message>
@@ -403,52 +431,52 @@ Are you OK to exit?</source>
 <context>
     <name>VariableEdit</name>
     <message>
-        <location filename="../VariableEdit.cpp" line="45"/>
+        <location filename="../VariableEdit.cpp" line="47"/>
         <source>Variables</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="50"/>
+        <location filename="../VariableEdit.cpp" line="52"/>
         <source>Mail:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="51"/>
+        <location filename="../VariableEdit.cpp" line="53"/>
         <source>Don&apos;t send</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="52"/>
+        <location filename="../VariableEdit.cpp" line="54"/>
         <source>Send</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="53"/>
+        <location filename="../VariableEdit.cpp" line="55"/>
         <source>To</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="65"/>
+        <location filename="../VariableEdit.cpp" line="67"/>
         <source>&amp;New</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="68"/>
+        <location filename="../VariableEdit.cpp" line="70"/>
         <source>&amp;Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="76"/>
+        <location filename="../VariableEdit.cpp" line="78"/>
         <source>Name:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="81"/>
+        <location filename="../VariableEdit.cpp" line="83"/>
         <source>Value:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VariableEdit.cpp" line="84"/>
+        <location filename="../VariableEdit.cpp" line="86"/>
         <source>Comment:</source>
         <translation type="unfinished"></translation>
     </message>
